.. :changelog:

History
=======

1.4.3
=====

* Remove tempdir storage location. Thanks to Kristian Glass.
* Make the SASS compiler compatible with more non-ruby SASS. Thanks to Corrado Primier.

1.4.2
=====

* Fix finder bug. Thanks to Quentin Pradet, Remi and Sam Kuehn for the report
* Update finders documentation. Thanks to Thomas Schreiber, Grégoire Astruc and Tobias Birmili for the report.

1.4.1
=====

* Fix storage logic. Thanks to Quentin Pradet for the report.

1.4.0
=====

* **BACKWARD INCOMPATIBLE** : Renamed templatetags library from ``compressed`` to ``pipeline``.
* **BACKWARD INCOMPATIBLE** : Renamed templatetag ``compressed_js`` to ``javascript``.
* **BACKWARD INCOMPATIBLE** : Renamed templatetag ``compressed_css`` to ``stylesheet``.
